@@ -671,22 +671,25 @@ class ConsumerThread(Thread):
                     time.sleep(0.1)
 
             except Exception:
-                logger.exception('Exception: Lost Connection during Fetch in Consumer Thread')
-                self.amqpconn.close()
-                time.sleep(1)
-                self.amqpconn = BrokerConnection(hostname=self.amqp_credentials.hostname,
-                                   port=self.amqp_credentials.port,
-                                   userid=self.amqp_credentials.username,
-                                   password=self.amqp_credentials.password,
-                                   virtual_host=self.amqp_credentials.vhost,
-                                   ssl=self.amqp_credentials.ssl)
+                try:
+                    logger.exception('Exception: Lost Connection during Fetch in Consumer Thread')
+                    self.amqpconn.close()
+                    time.sleep(1)
+                    self.amqpconn = BrokerConnection(hostname=self.amqp_credentials.hostname,
+                                       port=self.amqp_credentials.port,
+                                       userid=self.amqp_credentials.username,
+                                       password=self.amqp_credentials.password,
+                                       virtual_host=self.amqp_credentials.vhost,
+                                       ssl=self.amqp_credentials.ssl)
 
-                self.consumer.close()
-                                   
-                self.consumer = Consumer(connection=self.amqpconn,
-                                 queue=self.client_id + '_client_queue',
-                                 exchange=self.server_id + '_client_exchange',
-                                 routing_key=self.client_id + '_client_routing_key')
+                    self.consumer.close()
+
+                    self.consumer = Consumer(connection=self.amqpconn,
+                                     queue=self.client_id + '_client_queue',
+                                     exchange=self.server_id + '_client_exchange',
+                                     routing_key=self.client_id + '_client_routing_key')
+                except Exception:
+                    logger.exception('Exception: during reconnect')
 #===========================================================================
 class PublisherThread(Thread):
     """
