@@ -242,21 +242,24 @@ class QAMServer:
           else:
                 time.sleep(0.1)
         except Exception:
-            logger.exception('Exception: Connection Lost during fetch')
-            self.amqpconn.close()
-            time.sleep(1)
-            self.amqpconn = BrokerConnection(hostname=self.amqp_credentials.hostname,
-                                   port=self.amqp_credentials.port,
-                                   userid=self.amqp_credentials.username,
-                                   password=self.amqp_credentials.password,
-                                   virtual_host=self.amqp_credentials.vhost,
-                                   ssl=self.amqp_credentials.ssl)
-            self.consumer.close()
-                                   
-            self.consumer = Consumer(connection=self.amqpconn,
-                             queue=self.server_id + '_server_queue',
-                             exchange=self.server_id + '_server_exchange',
-                             routing_key=self.server_id + '_server_routing_key')
+            try:
+                logger.exception('Exception: Connection Lost during fetch')
+                self.amqpconn.close()
+                time.sleep(1)
+                self.amqpconn = BrokerConnection(hostname=self.amqp_credentials.hostname,
+                                       port=self.amqp_credentials.port,
+                                       userid=self.amqp_credentials.username,
+                                       password=self.amqp_credentials.password,
+                                       virtual_host=self.amqp_credentials.vhost,
+                                       ssl=self.amqp_credentials.ssl)
+                self.consumer.close()
+
+                self.consumer = Consumer(connection=self.amqpconn,
+                                 queue=self.server_id + '_server_queue',
+                                 exchange=self.server_id + '_server_exchange',
+                                 routing_key=self.server_id + '_server_routing_key')
+            except Exception, e:
+                logger.exception('Exception: during reconnection')
 
     self.finished = True
 
